@@ -4,8 +4,8 @@
 ObsChart API Wrapper
 """
 
-__title__ = 'obschart'
-__author__ = 'Deepscope'
+__title__ = "obschart"
+__author__ = "Deepscope"
 
 from .obschart_client import ObschartClient
 from .api.nodes import *
