@@ -4,14 +4,14 @@ from gql import gql
 import datetime
 import polling
 
-programTrackActionFragment = '''
+programTrackActionFragment = """
 fragment ProgramTrackAction on ProgramTrackAction {
     id
     sourceProgramModule {
         id
     }
 }
-'''
+"""
 
 
 class ProgramTrackAction(Node):
@@ -20,16 +20,20 @@ class ProgramTrackAction(Node):
 
     @property
     def module(self):
-        if not self._data['sourceProgramModule']:
+        if not self._data["sourceProgramModule"]:
             return None
 
-        return ProgramModule(self._data['sourceProgramModule'], self._context)
+        return ProgramModule(self._data["sourceProgramModule"], self._context)
 
     @property
     def responses(self):
-        from .program_track_action_response import ProgramTrackActionResponse, programTrackActionResponseFragment
+        from .program_track_action_response import (
+            ProgramTrackActionResponse,
+            programTrackActionResponseFragment,
+        )
 
-        query = gql('''
+        query = gql(
+            """
           query ProgramTrackActionResponsesQuery($programTrackActionId: ID)  {
             programTrackAction(id: $programTrackActionId) {
               responses(first: 9999) {
@@ -41,23 +45,24 @@ class ProgramTrackAction(Node):
               }
             }
           }
-          ''' + programTrackActionResponseFragment)
+          """
+            + programTrackActionResponseFragment
+        )
 
         variables = {}
-        variables['programTrackActionId'] = self.id
+        variables["programTrackActionId"] = self.id
         response = self._execute(query, variables)
 
         responses: list[ProgramTrackActionResponse] = []
-        for edge in response['programTrackAction']['responses']['edges']:
-            responses.append(ProgramTrackActionResponse(
-                edge['node'], self._context))
+        for edge in response["programTrackAction"]["responses"]["edges"]:
+            responses.append(ProgramTrackActionResponse(edge["node"], self._context))
 
         return responses
 
     def poll_responses(self):
-        return self._context.client.poll_program_track_action_responses({
-            'programTrackActionId': self.id
-        })
+        return self._context.client.poll_program_track_action_responses(
+            {"programTrackActionId": self.id}
+        )
 
     def wait_for_response(self):
         responses = self.poll_responses()
