@@ -1,6 +1,7 @@
 from ..node import Node
 from .program_track_action import ProgramTrackAction, programTrackActionFragment
 from gql import gql
+import json
 
 programTrackActionResponseFragment = (
     """
@@ -29,14 +30,23 @@ class ProgramTrackActionResponse(Node):
     def response(self):
         return self._data["response"]
 
+    def set_feedback_with_data(self, data_json):
+        data = json.loads(data_json.replace("\n", "\\n"))
+
+        pta = self._context.client.create_program_track_action(data)
+
+        self._context.client.update_program_track_action_response(self.id, pta.id)
+
+        return pta
+
     def set_feedback(self, title: str, blocks):
         data = {
             "type": "multiStep",
             "steps": [{"name": title, "action": {"type": "blocks", "blocks": blocks}}],
         }
 
-        pma = self._context.client.create_program_track_action(data)
+        pta = self._context.client.create_program_track_action(data)
 
-        self._context.client.update_program_track_action_response(self.id, pma.id)
+        self._context.client.update_program_track_action_response(self.id, pta.id)
 
-        return pma
+        return pta
